gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-donau] branch master updated: [donau] add donau os installation


From: gnunet
Subject: [taler-donau] branch master updated: [donau] add donau os installation
Date: Mon, 04 Dec 2023 22:34:52 +0100

This is an automated email from the git hooks/post-receive script.

lukas-matyja pushed a commit to branch master
in repository donau.

The following commit(s) were added to refs/heads/master by this push:
     new e049a63  [donau] add donau os installation
     new 11e828c  Merge remote-tracking branch 'refs/remotes/origin/master'
e049a63 is described below

commit e049a63eeb227af55b4855a16b9d6ee2ab158525
Author: Matyja Lukas Adam <lukas.matyja@students.bfh.ch>
AuthorDate: Mon Dec 4 22:34:27 2023 +0100

    [donau] add donau os installation
---
 src/donau/donau-httpd.c          |  3 ++-
 src/include/donau_util.h         | 13 +++++++++++++
 src/util/Makefile.am             |  3 ++-
 src/util/donau_os_installation.c | 19 ++++++++++---------
 4 files changed, 27 insertions(+), 11 deletions(-)

diff --git a/src/donau/donau-httpd.c b/src/donau/donau-httpd.c
index ddb78e2..8360e99 100644
--- a/src/donau/donau-httpd.c
+++ b/src/donau/donau-httpd.c
@@ -34,6 +34,7 @@
 #include "donaudb_plugin.h"
 #include "taler/taler_extensions.h"
 #include <gnunet/gnunet_mhd_compat.h>
+#include "donau_util.h"
 
 // /**
 //  * Backlog for listen operation on unix domain sockets.
@@ -1486,7 +1487,7 @@ main (int argc,
   enum GNUNET_GenericReturnValue ret;
   (void)options[0]; // delete me
   ret = 1; // delete me
-  // TALER_OS_init ();
+  DONAU_OS_init ();
   // ret = GNUNET_PROGRAM_run (argc, argv,
   //                           "taler-donau-httpd",
   //                           "Taler donau HTTP service",
diff --git a/src/include/donau_util.h b/src/include/donau_util.h
index 063b17b..5b84fc4 100644
--- a/src/include/donau_util.h
+++ b/src/include/donau_util.h
@@ -29,4 +29,17 @@
 #include <taler/taler_util.h>
 #include "donau_crypto_lib.h"
 
+/**
+ * Return default project data used by Taler.
+ */
+const struct GNUNET_OS_ProjectData *
+DONAU_project_data_default (void);
+
+
+/**
+ * Initialize libtalerutil.
+ */
+void
+DONAU_OS_init (void);
+
 #endif
diff --git a/src/util/Makefile.am b/src/util/Makefile.am
index d013566..c8f84cb 100644
--- a/src/util/Makefile.am
+++ b/src/util/Makefile.am
@@ -14,7 +14,8 @@ lib_LTLIBRARIES = \
 
 libtalerdonauutil_la_SOURCES = \
   charity_signatures.c \
-  donau_signatures.c 
+  donau_signatures.c \
+  donau_os_installation.c 
 
 libtalerdonauutil_la_LIBADD = \
   -ltalerutil \
diff --git a/src/util/donau_os_installation.c b/src/util/donau_os_installation.c
index f2c2d0b..6823fee 100644
--- a/src/util/donau_os_installation.c
+++ b/src/util/donau_os_installation.c
@@ -1,6 +1,6 @@
 /*
      This file is part of GNU Taler.
-     Copyright (C) 2016 Taler Systems SA
+     Copyright (C) 2023 Taler Systems SA
 
      Taler is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -18,11 +18,12 @@
      Boston, MA 02110-1301, USA.
 */
 /**
  * @file os_installation.c
  * @brief initialize libgnunet OS subsystem for Taler.
  * @author Christian Grothoff
+ * @author Lukas Matyja
  */
-#include "platform.h"
+#include "taler/platform.h"
 #include <gnunet/gnunet_util_lib.h>
 
 
@@ -38,7 +39,7 @@ static const struct GNUNET_OS_ProjectData donau_pd = {
   .base_config_varname = "TALER_BASE_CONFIG",
   .bug_email = "taler@gnu.org",
   .homepage = "http://www.gnu.org/s/taler/";,
-  .config_file = "taler.conf",
+  .config_file = "donau.conf",
   .user_config_file = "~/.config/donau.conf",
   .version = PACKAGE_VERSION "-" VCS_VERSION,
   .is_gnu = 1,
@@ -48,12 +49,12 @@ static const struct GNUNET_OS_ProjectData donau_pd = {
 
 
 /**
  * Return default project data used by Taler.
  */
 const struct GNUNET_OS_ProjectData *
-TALER_project_data_default (void)
+DONAU_project_data_default (void)
 {
-  return &taler_pd;
+  return &donau_pd;
 }
 
 
@@ -67,4 +68,4 @@ DONAU_OS_init ()
 }
 
 
-/* end of os_installation.c */
+/* end of donau_os_installation.c */
@@ -18,11 +18,12 @@
 */
 /**
- * @file os_installation.c
- * @brief initialize libgnunet OS subsystem for Taler.
+ * @file donau_os_installation.c
+ * @brief initialize libgnunet OS subsystem for Donau.
  * @author Christian Grothoff
@@ -48,12 +49,12 @@ static const struct GNUNET_OS_ProjectData donau_pd = {
 
 /**
- * Return default project data used by Taler.
+ * Return default project data used by Donau.
  */
 const struct GNUNET_OS_ProjectData *

-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]